@@ -1,6 +1,6 @@
 package Silki::Markdent::Handler::HeaderCount;
 BEGIN {
-  $Silki::Markdent::Handler::HeaderCount::VERSION = '0.08';
+  $Silki::Markdent::Handler::HeaderCount::VERSION = '0.09';
 }
 
 use strict;
@@ -41,29 +41,3 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Silki::Markdent::Handler::HeaderCount
-
-=head1 VERSION
-
-version 0.08
-
-=head1 AUTHOR
-
-  Dave Rolsky <autarch@urth.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2010 by Dave Rolsky.
-
-This is free software, licensed under:
-
-  The GNU Affero General Public License, Version 3, November 2007
-
-=cut
-
